package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.42.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.42.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````<R(```````!``````````""Q````
M`````````$``.``-`$``&0`8``8````$````0`````````!``````````$``
M````````V`(```````#8`@````````@``````````P````0```!L`P``````
M`&P#````````;`,````````9`````````!D``````````0`````````!````
M!````````````````````````````````````*`8````````H!@`````````
M$`````````$````%`````"``````````(``````````@````````'CP`````
M```>/``````````0`````````0````0`````8`````````!@`````````&``
M``````!H1P```````&A'`````````!`````````!````!@```-"K````````
MT+L```````#0NP```````%`$````````X`0`````````$`````````(````&
M````"*P````````(O`````````B\````````X`$```````#@`0````````@`
M````````!`````0````8`P```````!@#````````&`,````````P````````
M`#``````````"``````````$````!````$@#````````2`,```````!(`P``
M`````"0`````````)``````````$`````````%/E=&0$````&`,````````8
M`P```````!@#````````,``````````P``````````@`````````4.5T9`0`
M``"@H````````*"@````````H*````````#L`````````.P`````````!```
M``````!1Y71D!@``````````````````````````````````````````````
M```````````0`````````%+E=&0$````T*L```````#0NP```````-"[````
M````,`0````````P!`````````$`````````!````"`````%````1TY5``$`
M`<`$````"0`````````"``'`!`````$`````````!````!0````#````1TY5
M`*!.+-\%(*DB+@L22]HK\\Q1%ZH/+VQI8B]L9"UM=7-L+7@X-E\V-"YS;RXQ
M`````!$```!`````!`````@````@'!``!4`$@B@`$`2`A@"$@J$`(DD"!`FX
M@AA!N@0""D````!!````10```$D```!*````40```%(```!4`````````%@`
M``!9````6@```%L```!<````7@``````````````H^D9!,[>1RUNQ=\?:G^:
M?.O3[PXNQ9NVN(WQ#B#_Y`[59-1\V7%8'+(!BV^83\.;PN4_+$+ZUX?ZH6Q@
MNN.2?.-'Q@%5PSS29J_,9L6YG$"(!W#3Q(D%D#CRBQQ#1=7L,V+;[16,)<RG
MW:-K?ZF<F^"G`@IK&IY0HN#[20N*$%<`````````````````````````````
M````````=@(``!(`````````````````````````FP$``!(`````````````
M````````````4@```!(`````````````````````````O`(``!(`````````
M````````````````;P$``!(`````````````````````````/0```!(`````
M````````````````````&0$``!(`````````````````````````W@$``!(`
M````````````````````````J@```!(`````````````````````````LP``
M`"(`````````````````````````.`$``!(`````````````````````````
MPP$``!(`````````````````````````9`(``!(`````````````````````
M````@`$``!(`````````````````````````_````!(`````````````````
M````````?0(``!(`````````````````````````-P```!(`````````````
M````````````)P$``!(`````````````````````````30(``!(`````````
M````````````````8@```!(`````````````````````````_0$``!(`````
M````````````````````FP```!(`````````````````````````)`(``!(`
M````````````````````````'P```"``````````````````````````30$`
M`!(`````````````````````````W0```"``````````````````````````
M:@```!(`````````````````````````]P```!(`````````````````````
M````6@```!(`````````````````````````2P```!(`````````````````
M````````$````!(`````````````````````````&P(``!(`````````````
M````````````E`(``!(`````````````````````````CP$``!(`````````
M````````````````>0```"``````````````````````````C0(``!(`````
M````````````````````/0(``!(`````````````````````````Z@$``!(`
M`````````````````````````0```!(`````````````````````````1```
M`!(`````````````````````````\@,``!(`````````````````````````
M+P(``!(`````````````````````````A0(``!(`````````````````````
M````"P(``!(`````````````````````````:P```!(`````````````````
M````````:P(``!(`````````````````````````&````!(`````````````
M`````````````@$``!(`````````````````````````V````!(`````````
M````````````````7`$``!8`````````````````````````FP(``!(`````
M````````````````````J@(``!(`````````````````````````(`$``!(`
M````````````````````````E0```!(`````````````````````````HP``
M`!(`````````````````````````<````!(`````````````````````````
M/P$``!(`````````````````````````6`(``!(`````````````````````
M````$P$``!(`````````````````````````P@```"``````````````````
M````````U`$``!(`````````````````````````F@```!(`````````````
M````````````V0$``!(`````````````````````````Q0(``"$`%@`@P```
M``````@`````````>@,``!(`"P"P-@```````.0&````````AP,``!(`"P``
M0````````,H`````````MP(``!(`"P!@(````````!,"````````L`$``!(`
M#``;7`````````$`````````_@(``!(`"P"@*@````````4`````````_@,`
M`!(`"0``(`````````$`````````,P,``!(`"P"P*@```````"<"````````
M2`,``!(`"P"@/0```````%,"````````DP,``!``%@`@P```````````````
M````&0,``!(`"P!`,P```````&(`````````0`,``!(`"P"P,P```````+$`
M````````7@,``!(`"P!`*0```````"8`````````;P,``!(`"P"05P``````
M`#\"````````GP,``!(`"P#@-0```````,4`````````S@,``!``%@"PP```
M````````````````TP,``!(`"P#@+````````"0`````````9@,``!(`"P")
M(@```````",`````````)P,``!(`"P`0+0```````"(!````````Q@(``!$`
M%@`@P`````````@`````````#P,``!$`%0`8P`````````@`````````QP(`
M`"$`%@`@P`````````@`````````"0```!$`$@``O`````````@`````````
MQP,``!``%0`@P```````````````````F`,``!``"P!S(@``````````````
M````^P,``!(`"P!`5P```````$8`````````R`(``"$`%@`@P`````````@`
M````````X`,``!(`"P#`-0```````!\`````````L0,``!(`"P!P*0``````
M`"H!````````!`0``!(`"P#060```````$L"````````\0(``!(`"P!`+@``
M`````/4$````````M@$``!$`%@`HP`````````$``````````&]P96YD:7(`
M<W1D97)R`')E86QL;V,`86-C97-S`%]?9&5R96=I<W1E<E]F<F%M95]I;F9O
M`&QS965K`&=E='!I9`!S=')C;7``=6YL:6YK`&UE;6UO=F4`<W1R;F-M<`!S
M=')R8VAR`&QS=&%T`&-L;W-E9&ER`%])5$U?9&5R96=I<W1E<E1-0VQO;F54
M86)L90!O<&5N`'9F<')I;G1F`'-T<F-H<@!R96%D;&EN:P!?7V-X85]F:6YA
M;&EZ90!?7W)E9VES=&5R7V9R86UE7VEN9F\`97AI=`!?251-7W)E9VES=&5R
M5$U#;&]N951A8FQE`')E860`<FUD:7(`7U]E<G)N;U]L;V-A=&EO;@!M:V1I
M<@!M96UC<'D`<W1R;&5N`%]?<W1A8VM?8VAK7V9A:6P`9V5T=6ED`%!E<FQ?
M<WES7W1E<FT`4&5R;%]S>7-?:6YI=#,`4$Q?8W5R<F5N=%]C;VYT97AT`%!E
M<FQ?871F;W)K7VQO8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]G971?<W8`4&5R
M;%]C<F]A:U]N;V-O;G1E>'0`7V9I;FD`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W
M6%-?9FQA9W,`<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N
M;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!0
M97)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?
M<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`<W1R8W!Y`')E
M861D:7(`<W!R:6YT9@!S=')D=7``<W1R=&]K`'!T:')E861?871F;W)K`%]?
M;&EB8U]S=&%R=%]M86EN`'-N<')I;G1F`%]?7V5N=FER;VX`;&EB<&5R;"YS
M;P!L:6)C+FUU<VPM>#@V7S8T+G-O+C$`<&%R7VEN:71?96YV`'!A<E]C=7)R
M96YT7V5X96,`;7E?<&%R7W!L`'!A<E]E;G9?8VQE86X`<&%R7V1I<FYA;64`
M<&%R7V9I;F1P<F]G`'!A<E]D:64`6%-?26YT97)N86QS7U!!4E]"3T]4`'AS
M7VEN:70`7W-T87)T7V,`<VAA7W5P9&%T90!P87)?;6MT;7!D:7(`<&%R7V-L
M96%N=7``7U]B<W-?<W1A<G0`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V-U<G)E
M;G1?97AE8U]P<F]C`%]E9&%T80!?96YD`'!A<E]B87-E;F%M90!G971?=7-E
M<FYA;65?9G)O;5]G971P=W5I9`!S:&%?:6YI=`!S:&%?9FEN86P`+W5S<B]L
M:6(O<&5R;#4O8V]R95]P97)L+T-/4D4``````-"[````````"`````````"`
M(P```````-B[````````"``````````@(P```````."[````````"```````
M```_80```````.B[````````"`````````#:8````````/"[````````"```
M``````#W8````````/B[````````"`````````!080````````#`````````
M"```````````P````````!C`````````"`````````#H8@````````B^````
M````!@````$``````````````!"^````````!@````(``````````````!B^
M````````!@````,``````````````""^````````!@````0`````````````
M`"B^````````!@````4``````````````#"^````````!@````8`````````
M`````#B^````````!@````<``````````````$"^````````!@````@`````
M`````````$B^````````!@````D``````````````%"^````````!@````H`
M`````````````%B^````````!@````L``````````````&"^````````!@``
M``P``````````````&B^````````!@````T``````````````'"^````````
M!@````X``````````````'B^````````!@````\``````````````("^````
M````!@```!```````````````(B^````````!@```!$``````````````)"^
M````````!@```!(``````````````)B^````````!@```!,`````````````
M`*"^````````!@```!0``````````````*B^````````!@```!4`````````
M`````+"^````````!@```!8``````````````+B^````````!@```!<`````
M`````````,"^````````!@```!@``````````````,B^````````!@```!D`
M`````````````-"^````````!@```!H``````````````-B^````````!@``
M`!L``````````````."^````````!@```!P``````````````.B^````````
M!@```!T``````````````/"^````````!@```!X``````````````/B^````
M````!@```!\```````````````"_````````!@```"````````````````B_
M````````!@```"$``````````````!"_````````!@```"(`````````````
M`!B_````````!@```",``````````````""_````````!@```"0`````````
M`````"B_````````!@```"4``````````````#"_````````!@```"8`````
M`````````#B_````````!@```"<``````````````$"_````````!@```"@`
M`````````````$B_````````!@```"D``````````````%"_````````!@``
M`"H``````````````%B_````````!@```"L``````````````&"_````````
M!@```"P``````````````&B_````````!@```"T``````````````'"_````
M````!@```"X``````````````'B_````````!@```"\``````````````("_
M````````!@```#```````````````(B_````````!@```#$`````````````
M`)"_````````$@```#(``````````````)B_````````!@```#,`````````
M`````*"_````````!@```#4``````````````*B_````````!@```#8`````
M`````````+"_````````!@```#<``````````````+B_````````!@```#@`
M`````````````,"_````````!@```#D``````````````,B_````````!@``
M`#H``````````````-"_````````!@```#L``````````````-B_````````
M!@```#P``````````````."_````````!@```#T``````````````.B_````
M````!@```#X``````````````/"_````````!@```#\```````````````"\
M````````!0```%8``````````````"#`````````!0```%,`````````````
M`"C`````````!0```%\```````````````"^````````!P```#0`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!06,,`````````````````_S7:G0``_R7<G0``#Q]``/\EVIT``&@`````
MZ>#___\`````````````````````#PL/"V8N#Q^$``````!F+@\?A```````
M#Q^$``````!54TB#[#B)?"0<2(U\)!Q(B70D$$B-="002(E4)`AD2(L4)2@`
M``!(B50D*$B-5"0(_Q4QG@``2(LUDIX``$B+/8.=``!(B?+_%>J>``"`/7.?
M````#X0?`0``2(L%SIX``&1(BP"`B#H$```#BT0D'(UX!(U8`TAC_TC!YP/_
M%>2>``!(BWPD$$2+1"0<2(G!2(D%J)\``$B+!TB)`4B-!=-```!(B4$(2(L%
M")\``$B)01!(C07`0```2(E!&$&#^`$/CB\!``!(@\<(08/``[H$````9BX/
M'X0``````$B+!TAC\H/"`4B#QPA(B03Q1#G"=>I(8])%,<!(BSU%GP``2(TU
MA@<``$C'!-$`````B=K_%1Z=``"%P`^$B@```$B-;"0D2(L]&I\``/\5O)T`
M`$B)[DB-/?8^``")P^@;`@``2(7`='1(BSWWG@``_Q4IG@``_Q4#G@``2(M$
M)"AD2"L$)2@````/A9P```!(@\0XB=A;7</_%9"=``!(B07!G@``2(G'2(7`
M='/_%7N<``!(BP64G0``9$B+$,:"]@@```#IMO[__TB+/96>``#_%>><``#I
M9/___TB+/7.>``!(A?]T"NC1'0``Z7;___](C3T./@``2(GNZ'T!``!(B05.
MG@``2(G'2(7`#X14____Z]*Z!````.GT_O__OP$```#_%1N=``#_%1V<``!(
M,>U(B>=(C36(F0``2(/D\.@`````BS=(C5<(3(T%A3D``$4QR4B-#6#]__](
MC3VY_?__Z73]__\/'T``2(T]:9T``$B-!6*=``!(.?AT%4B+!4Z<``!(A<!T
M"?_@#Q^``````,,/'X``````2(T].9T``$B--3*=``!(*?Y(B?!(P>X_2,'X
M`T@!QDC1_G042(L%Q9L``$B%P'0(_^!F#Q]$``###Q^``````(`]&9T```!U
M1U5(@ST>FP```$B)Y70-2(L]PIP``/\5#)L``.AG____2(,];YL```!T#4B-
M/79^``#_%6";``#&!=F<```!7<,/'X``````PV9F+@\?A```````#Q]``$B#
M/5"<````="952(TUSIP``$B-/3=^``!(B>7_%3:<``!=Z3C___\/'X0`````
M`.DK____9BX/'X0``````)!!5T%6055!5%532(/L"$R+-4N<``!-A?8/A)0`
M```/M@=)B?])B?6$P'0$/#UU444QY$F+'DB%VW0M36/D3(GU3(GB3(G^2(G?
M_Q79F@``A<!U!T*`/",]=$9(BUT(2(/%"$B%VW792(/$"$B)V%M=05Q!74%>
M05_##Q^``````$F)_$$/MD0D`4F#Q`&$P'0$/#UU[D4I_.N89@\?1```3"GU
M2HU<(P%(P?T#08EM`.NU,=OKL68N#Q^$``````!32('LH````&1(BQPE*```
M`$B)G"28````2(G[2(GF_Q4SF@``A<!U-XM4)!B!X@#P``"!^@!```!T"('Z
M`*```'4?O@(```!(B=__%:>:``"%P`^4P`^VP.L'#Q]$```QP$B+E"28````
M9$@K%"4H````=0E(@<2@````6\/_%8R9``!F9BX/'X0``````)!!54%455-(
M@>RH````9$B+!"4H````2(F$))@````QP$B%_W0(@#\`2(G[=2M(BX0DF```
M`&1(*P0E*`````^%(P$``$B!Q*@```!;74%<05W#9@\?1```_Q7*F0``2(G%
M2(7`=,=(B>__%0&9``!(A<`/A*@```"`>!,N3(U@$W4.08!\)`$`=-QF#Q]$
M``"`>!,N#X2F````2(G?_Q7MF0``3(GG28G%_Q7AF0``08U\!0)(8___%9N8
M``!,B>%(B=I(C34F.@``28G%2(G',<#_%7"9``!,B>](B>;_%729``!,B>^#
M^/]T$(M$)!@E`/```#T`0```=&3_%=Z8``!,B>__%=69``!(B>__%5R8``!(
MA<`/A5O___\/'P!(B>__%7^9``!(B=__%3:8``#I]O[__V8/'X0``````$&`
M?"0!+@^%3O___T&`?"0"``^$#O___^D]____#Q\`Z)O^___KF_\5$Y@```\?
M`$%7,<!!5D%505154TB)^TB#["B`/CUD2(LL)2@```!(B6PD&$B)]0^4P$@!
MQ4B)[_\5ZI@``$B-="042(G?28G$Z/K\__](A<`/A"D!``!)B<5(B<?_%<68
M``!,.>`/@_0```!,8W0D%$G!Y@,/M@.$P`^$T`$``#P]#X3(`0``2(G89F8N
M#Q^$``````!F9BX/'X0```````\?@``````/ME`!2(/``832=`6`^CUU[T@I
MV$B83(LMXY@``$J-?"`"_Q4@EP``30'U28E%`$B%P'1=2(L%Q9@``$B-2P%*
MBQ0P#[8#B`(\/70IA,!U%.LC9F8N#Q^$```````/'P`\/701#[8!2(/"`4B#
MP0&(`H3`=>O&`CTQP&8/'T0```^V3`4`B$P"`4B#P`&$R77O2(M$)!AD2"L$
M)2@````/A1<!``!(@\0H6UU!7$%=05Y!7\,/'T``,<!F#Q]$```/ME0%`$&(
M5`4`2(/``832=>[KO0\?0`!,BSTAF```28,_``^$Q@```$R)^$4Q[69F+@\?
MA```````9@\?1```2(/`"$2)ZD&#Q0%(@S@`=>^-<@-(8_9(P>8#BP5/F```
MA<!U6\<%09@```$```!(B??_%1"6``!(A<`/A%#___]-8_5(B40D"$R)_DB)
MQTG!Y@-,B?+_%9R5``!(BTPD"$B)#9B7``!!C44!1(EL)!1(F$C'!,$`````
MZ4W^__],B?__%4^6``!(B05PEP``2(G!2(7`#X3U_O__36/U2<'F`^O##Q\`
M,<#I9_[__[X0````13'MZ5______%:Z5``!F9BX/'X0```````\?`%-(BQV8
ME@``2(T-87<``$B--0`W``!(BQ4;E@``9$B+._\5H94``$R-!9<X``!D2(L[
M6T4QR4R)P4B-%7`4``!(C37K-@``_R4CE0``#Q\`2(L%298``$B+%=J5``!(
MC0T+=P``2(TUJC8``&1(BSC_)5*5``!F+@\?A```````55-(@>P`$```2(,,
M)`!(@>P`$```2(,,)`!(@^PH9$B+!"4H````2(F$)!@@```QP/\5B90``$R-
M!8DV``"^`1```$B)YXG!2(T5?#8``#'`_Q59E```@_C_#X3`````2)A(/0`0
M```/AV+V__](C:PD$!```+H`$```2(GG2(GN_Q51E```2(G#A<`/B(X```"-
M>`%(8___%5J4``!(B<%(A<!T>DACVT@YZ',-2(T$&$@YQ0^"%?;__T@YS7)(
M2('[`1````^'`_;__TB)STB)VDB)[O\5[),``,8$&`!(B<%(BX0D&"```&1(
M*P0E*````'4N2('$*"```$B)R%M=PP\?1```2(U$'0!(.<%SKNFY]?__9@\?
MA```````,<GKO_\5]I,``&8/'T0``.G+_O__9F8N#Q^$``````!!5T%6055!
M5%532('L`!```$B##"0`2('LN````&1(BQPE*````$B)G"2H$```2(GS28G\
M2(UT)`Q(C3U9-0``Z,OX__^^+P```$R)YTB)Q?\5JI0``$B%P'1%3(GF2(T]
M/34``.AF^___3(G@2(N4)*@0``!D2"L4)2@````/A9T!``!(@<2X$```6UU!
M7$%=05Y!7\-F+@\?A```````2(G?3(TM!34``$R--0DV``#_%;F3``!,B>Y(
MB<?_%963``!(B<-(A<!TD(`[``^$CP```&9F+@\?A```````D$B%[7002(G>
M2(GO_Q6?DP``A<!T3DB)W_\5\I,``$B-5`/_28G'2#G3<A'K(`\?`,8"`$B#
MZ@%(.=-T!8`Z+W3O2(G?_Q7&DP``28G'3(GG_Q6ZDP``28U$!P)(/?\/``!V
M34R)[C'__Q4*DP``2(G#2(7`#X0!____@#L`#X5]____2(7M=`:`?0`N=!)!
MOP$```!(C1T<-```Z[`/'P"`?0$`=+WKY@\?A```````3(V\)*````!-B>%(
MB=DQP$R-!0HT``!,B?*^`!```$R)__\5N)$``(/``3T`$```=@(/"TB-="00
M3(G__Q7FD@``A<`/A6G___^+1"0H)0#P```]`(````^%5?___[X!````3(G_
M_Q7,D@``A<`/A3____],B?Y(C3V4,P``Z+WY__],B?__%522``#I3/[___\5
MN9$``&8/'X0``````%.^+P```$B)^_\5L9$``$B-4`%(A<!(#T7:2(G?6_\E
M')(``&9F+@\?A```````D%532('L`!```$B##"0`2(/L&&1(BP0E*````$B)
MA"0($```,<!(A?\/A+(```"`/P!(B?T/A*8```#_%5"2``!(@\`!2#T`$```
M#X?(````2(GN2(GG2(GC_Q69D```2(GG_Q4HD@``2(U$!/](.<1R*NLM9F8N
M#Q^$``````!F9BX/'X0``````&8/'T0``,8``$B#Z`%(.=AT!8`X+W3OOB\`
M``!(B=__%>&0``!(A<!T+$@YPW)72(G?_Q5.D0``2(N4)`@0``!D2"L4)2@`
M``!U1TB!Q!@0``!;7<.02(N$)`@0``!D2"L$)2@```!U*4B!Q!@0``!(C3TV
M,@``6UW_)0>1```/'X``````Q@``ZZ0/'P`QP.NF_Q5>D```9F8N#Q^$````
M```/'P!!5T%6055!5%5(C2T3,@``4TB#[!AD2(L<)2@```!(B5PD"$B-7"0$
M2(G>2(GOZ$WU__](A<!T2$AC5"0$2(L%G)$``$B-!-!(BU`(2(D02(72=-1F
M9BX/'X0``````)!(BU`02(/`"$B)$$B%TG7P2(G>2(GOZ`7U__](A<!UN$B-
M+:4Q``!(B=Y(B>_H[O3__TB%P'1)2&-4)`1(BP4]D0``2(T$T$B+4`A(B1!(
MA=)TU&9F+@\?A```````9I!(BU`02(/`"$B)$$B%TG7P2(G>2(GOZ*7T__](
MA<!UMTB-+4TQ``!(B=Y(B>_HCO3__TB%P'1)2&-4)`1(BP7=D```2(T$T$B+
M4`A(B1!(A=)TU&9F+@\?A```````9I!(BU`02(/`"$B)$$B%TG7P2(G>2(GO
MZ$7T__](A<!UMTB-+?8P``!(B=Y(B>_H+O3__TB%P'1)2&-4)`1(BP5]D```
M2(T$T$B+4`A(B1!(A=)TU&9F+@\?A```````9I!(BU`02(/`"$B)$$B%TG7P
M2(G>2(GOZ.7S__](A<!UMTB-+9TP``!(B=Y(B>_HSO/__TB%P'1)2&-4)`1(
MBP4=D```2(T$T$B+4`A(B1!(A=)TU&9F+@\?A```````9I!(BU`02(/`"$B)
M$$B%TG7P2(G>2(GOZ(7S__](A<!UMTR-)4TP``!(B=Y,B>?H;O/__TB%P'1)
M2&-4)`1(BP6]CP``2(T$T$B+4`A(B1!(A=)TU&9F+@\?A```````9I!(BU`0
M2(/`"$B)$$B%TG7P2(G>3(GGZ"7S__](A<!UMTR-):(O``!(B=Y,B>?H#O/_
M_TB%P'1)2&-4)`1(BP5=CP``2(T$T$B+4`A(B1!(A=)TU&9F+@\?A```````
M9I!(BU`02(/`"$B)$$B%TG7P2(G>3(GGZ,7R__](A<!UMTR--9DO``!(B=Y,
MB??HKO+__TB%P'1)2&-4)`1(BP7]C@``2(T$T$B+4`A(B1!(A=)TU&9F+@\?
MA```````9I!(BU`02(/`"$B)$$B%TG7P2(G>3(GWZ&7R__](A<!UMTR-+4,O
M``!(B=Y,B>_H3O+__TB%P'1)2&-4)`1(BP6=C@``2(T$T$B+4`A(B1!(A=)T
MU&9F+@\?A```````9I!(BU`02(/`"$B)$$B%TG7P2(G>3(GOZ`7R__](A<!U
MMTR-/>TN``!(B=Y,B?_H[O'__TB%P'1)2&-4)`1(BP4]C@``2(T$T$B+4`A(
MB1!(A=)TU&9F+@\?A```````9I!(BU`02(/`"$B)$$B%TG7P2(G>3(G_Z*7Q
M__](A<!UMTR-/2LN``!(B=Y,B?_HCO'__TB%P'1)2&-4)`1(BP7=C0``2(T$
MT$B+4`A(B1!(A=)TU&9F+@\?A```````9I!(BU`02(/`"$B)$$B%TG7P2(G>
M3(G_Z$7Q__](A<!UMTB)WDB-/30N``#H,?'__TB%P'0+2(G&3(GOZ.'S__](
MB=Y(C3TF+@``Z!+Q__](A<!T#TB)QDB-/20N``#HOO/__TB)WDB-/2`N``#H
M[_#__TB)QDB%P'0U3(GGZ)_S__](BT0D"&1(*P0E*````'4^2(/$&$B)[TB-
M-0XN``!;74%<05U!7D%?Z7+S__](B=Y(C3WD+0``Z*/P__](A<!TOTB)QDR)
M]^A3\___Z[+_%5N+``!F9BX/'X0``````$B#[!A(C3U5+0``9$B+-"4H````
M2(ET)`A(C70D!.A=\/__2(7`=#`/MA"`^C`/E,"$T@^4P@G0@_`!#[;`2(M4
M)`AD2"L4)2@```!U#DB#Q!C##Q]$```QP.OB_Q7NB@``9F8N#Q^$```````/
M'P!06$B![-@```!(B70D*$B)5"0P2(E,)#A,B40D0$R)3"1(A,!T-P\I1"10
M#RE,)&`/*50D<`\IG"2`````#RFD))`````/*:PDH`````\IM"2P````#RF\
M),````!D2(L$)2@```!(B40D&#'`2(V$).````!(B?Y(B>)(B40D"$B-1"0@
M2(L]Q(<``,<$)`@```#'1"0$,````$B)1"00_Q62BP``O_\```#_%2>+``!F
M9BX/'X0```````\?0`!!5%533(V<)```__](@>P`$```2(,,)`!,.=QU[TB#
M[!"Z`@```#'V9$R+)"4H````3(FD)`@``0!!B?Q(B>/_%=.)``!(C6C_2(GJ
M2,'Z/TC!ZC!(C405``^WP$@IT$@IQ0^(O`````\?A```````,=)(B>Y$B>?_
M%9J)``!(@_C_#X2S````N@@``0!(B=Y$B>?_%=>)``"#^/\/A(L```!(F$B#
M^`=V9DB-1`/X2#G8<EQ(C17=B@``ZQQF9BX/'X0```````\?A```````2(/H
M`4@YV'(W2(L(2#D*=>](*=A(`>A(BY0D"``!`&1(*Q0E*````'5/2('$$``!
M`%M=05S#9BX/'X0``````$B![0```0!(@?T``/__#X5,____2,?`_____^NZ
M2(T]>"L``#'`Z`7^__](C3U=*P``,<#H]_W___\5T8@``)!(@^P(_Q6.B```
MB<?_%7:)``!(A<!T`TB+`$B#Q`C#D$%5051,C24]*P``55-(@^P89$B++"4H
M````2(EL)`A(B?U(C70D!$R)Y^BQ[?__2(7`=`B`.`!(B<-U+$B+1"0(9$@K
M!"4H````=7-(B>Y(@\083(GG6UU!7$%=Z3_P__\/'X``````2(GO_Q5/B0``
M2(G?28G%_Q5#B0``28U\!0+_%0"(``!)B=A(B>I(C0WJ*0``28G%2(G'2(TU
MZ"H``#'`_Q7.B```2(M$)`AD2"L$)2@```!U!4R)[NN0_Q7KAP``9F8N#Q^$
M``````!!5TB-!8XI``!!5F9(#V[(2(T%?2H``$%59D@/;M!(C05W*@``051F
M2`]NV$B-!7(J``!59D@/;N!32('L>`$``/,/?@7GA```9$R+/"4H````3(F\
M)&@!``!)B?](C6PD'$B-/3`I``!(QT0D,`````!(QT0D4`````!F#VS!2(GN
M#RE$)"#S#WX%J80``$C'A"2(`````````&8/;,(/$40D:/,/?@64A```9@]L
MPP\11"1X\P]^!8N$``!F#VS$#RE$)$#H1>S__TB%P'0,@#@`2(G##X6$!```
M_Q7&A@``B<?_%:Z'``!(A<`/A,T#``!,BRA-A>T/A,$#``!,B>__%>B'``!(
MC7P``?\5I88``$$/ME4`2(D$)$F)QH32="],C26$*0``9@\?1```28/%`0^V
MTDR)]TR)YC'`28/&`O\57X<``$$/ME4`A-)UWDR-;"1@2(T]TR@``.L-28M]
M"$F#Q0A(A?]T,TB)[NB;Z___28G$2(7`=..`.`!TWDB)Q^A&[/__A<!TTDR)
MY_\5V88``$B)PTB%P'4VD$R-9"0@28L<)$B%VW0G@#L`#X3Y`@``2(G?Z!'L
M__^%P`^%^0```$F+7"0(28/$"$B%VW792(G?_Q42AP``3(LT)$F)Q$R)]_\5
M`H<``$&-A`0$!```3&/@3(GG_Q6VA0``38GQ3(TUI2<``$B)VDF)Q4B)QTB-
M-9PH```QP$R-!8XH``!,B?'_%7J&``"^P`$``$R)[_\5Y(8``(/X_W43_Q6)
MA@``1(L`08/X$0^%XP(``$B-M"20````3(GO_Q7#A0``B<.%P'1U28L72(L]
MVX(``$R)Z3'`2(TU[R@``/\5>84``$4QY&8/'T0``$B+A"1H`0``9$@K!"4H
M````#X4I!```2('$>`$``$R)X%M=05Q!74%>05_##Q]``$B)WTF#Q`C_%:.%
M``!(B<-(A<`/A,S^___I]_[__V:0BX0DJ````"4`\```/0!````/A73___^+
MA"2L````B00D_Q6AA```.00D#X5;____BX0DJ````"7_`0``/<`!```/A43_
M__],B>?_%8B$``!(B>Y(C3U))P``28G$Z,[I__](A<`/A%4"``!)BS](B<;H
MJO#__TB)!"1(A<`/A#T"``!(BSPD_Q6#A0``2(G"@_@#?DM(BPPD2)A(B50D
M"$B--3HG``!(C7P!_/\5_H0``(7`=2I(BU0D"(/Z!`^$Z@(``$B+#"2-0OM(
MF(`\`2\/A-<"``!F#Q^$``````!(B>Y(C2TF)@``2(GOZ#[I__](A<`/A-4!
M```/M@"$P`^$R@$``#PP#X3"`0``2(GO2(TU928``$R-/08G``#HS.O__TB-
M+>@F``#_%6^#``!,B?%,B>I,B>=!B<!,C0WA)@``2(TUNB8``#'`_Q5UA```
MZSD/'P#_%9*$``"#.!%U/O\5-X,``(/#`4B#[`A,B>I!5T&)P$&)V4R)\4B)
M[DR)YS'`_Q4\A```6%J^P`$``$R)Y_\5I(0``(/X_W2W3(GO_Q6VA```3(GF
M2(T]!24``.@WZ___3(GGZ(_Z___IZOW__V8N#Q^$```````QV^D>_?__9@\?
MA```````2(U<)$!F9BX/'X0``````$B+.TB%_W0B2(GNZ##H__](B<=(A<!T
M!8`X`'4S2(M["$B#PPA(A?]UWK\-````3(TM@B4``/\5K((``+I3````2(D$
M)$F)QND&_/__#Q\`_Q5*@P``2(/#"$F)Q4B%P'2>Z<C[__])BQ=(BST/@```
M3(GI,<!(C37C)0``_Q6M@@``Z2_]__\/'X0``````$B)Q^C(^?__2(N$)&@!
M``!D2"L$)2@````/A5$!``!(@<1X`0``2(G?6UU!7$%=05Y!7_\EUX(```\?
M@`````!)BP=(B00DZ;?]__\/'T``2(L\)#'V,<#_%3J#``!!B<>%P`^$)?[_
M_XG'Z/#W__](A<`/B!7^__\QTDB-</9$B?](B00D_Q7L@0``2(VT)"H!``"Z
M!@```$2)__\5+H(``$B+#"1(@_@&#X7&````@;PD*@$```!#04,/A<W]__]F
M@;PD+@$``$A%#X6]_?__2(V<)#`!```QTDB-<<Y$B?__%9"!``"Z*````$B)
MWD2)__\5UX$``$B#^"AU=\:$)%@!````28G83(GQ,<!,C0V/)```3(GJ2(TU
M5B0``$R)Y_\5'X(``.GS_?__38M_"$V%_P^$)?W__TR)__\53((``$B#^`,/
MAA+]__])C7P'_$B--0PD``#_%="!``"%P$P/13PD3(D\).GP_/___Q4*@0``
M2(T][B,``#'`Z!SV__]F9BX/'X0``````)!!54B-/=LB``!!5%532(/L&&1(
MBQPE*````$B)7"0(2(L=RH$``$R-9"0$3(GF9$B+*P^VA;````"(A;$```#H
MW.7__TB%P'0)@#@Q#X1F`0``,<#H1_#__V1(BRM(B>^Y`P```+H!````2(TU
MHR,``/\528$``$B)Q4B%P'0I2(M`$&1(BSM(C16((P``2(LP_Q5Q@```2(M%
M$$B+,/9&#D`/A5@!``!D2(L[N0,```"Z`0```$B--5XC``#_%?V```!(B<5(
MA<!T+$R)YDB-/=TA``#H1N7__TB)PDB%P`^$Z@```$B+11!D2(L[2(LP_Q41
M@```9$B+.[H!````2(TU%B,``/\58X```&1(BSM(C14:(P``2(G&_Q7G?P``
M9$B+`TB-/7TA``!,B>;&@+$`````Z.7D__](B06V@0``2(G'2(7`=#Z^P`$`
M`/\5VX```(U0`8/Z`78)@_@1#X6I````2(M$)`AD2"L$)2@````/A=,```!(
M@\086UU!7$%=PP\?`$B+/7&!``#H?/?__TB)!5V!``!(B<=(A<!UITB-/2XC
M```QP/\5OGX``&8/'T0``(!X`0`/A)O^___IB_[__V8/'X0``````.C[Z?__
M9$B+.TF)Q4B+11!(BS!-A>UT4$R)ZO\5%W\``$R)[_\55H```.GX_O__D&1(
MBSO_%99^``#IF?[__XG!2(L%Z(```$B+%=F```!(C3W:(@``2(LP,<#_%3]^
M```/'X``````2(L%P8```$B+$/\5P'X``.FJ_O___Q6=?@``9F8N#Q^$````
M``!FD%532(/L&&1(BQPE*````$B)7"0(2(G[2(UT)`1(C3U](```Z)CC__](
MA<!T'`^V$(32#Y3`@/HP#Y3""-!U"DB%VW0%@#L`=1=(BT0D"&1(*P0E*```
M`'5K2(/$&%M=PTB)W^BH[/__OB\```!(B<5(B<?_%2=^``!(C5`!2(7`2`]%
MZDB)[_\5DWX``+H$````2(TURB```$B)Q_\51GX``(7`=:-(BT0D"&1(*P0E
M*````'4.2(/$&$B)WUM=Z4SD____%<9]``!F#Q]$``!!5T%6055!5%532('L
MF`(``&1(BS0E*````$B)M"2(`@``2(G^2(GB3(V,)(````!(B>=,C48X9@\?
MA```````08L`38L02(/'$$F#P`@/R(G`3(G12(E'\$R)T$C!Z2!(P>@H2<'J
M."4`_P``3`G028G*2,'A"$G!XAB!X0``_P!%B=),"=!("<A(B4?X3#G/=:V[
M_____V8/;T0D$$B-1"1H9@]O7"0@9D@/;NMF#V]4)#!(@<)H`@``9@]L[9#S
M#V\(9@]OXF8/;U#82(/`$&8/[T"(9@_ORF8/[\%F#V_(9@]S\`%F#W/1'V8/
MZ\%F#]O%#RE`"&8/;\-F#V_<2#G0=;M,BPY,BUX02(M^($B+7AA,B<A,B<I(
MBVX(2(M,)`A(P>H;2,'@!4@)T`,$)$B-C`N9>8):C90XF7F"6DR)V$@QV$@A
MZ$@QV(T\`DB)ZDB)Z$C!Z`)(P>(>28GZ2`G"3(G82<'J&T&)T$PQP$PAR$PQ
MV$@!R$B)^4C!X05,"=%,BU0D$$2-)`A,B<A,B<E(P>D"2,'@'D^-E!.9>8):
M38GE2`G(2<'M&T@QPHG!2"'Z3#'"3`'238GB2<'B!4T)ZDR+;"0800'22(GZ
M2,'O`DC!XAY%B=)/C80HF7F"6D@)^DV)U4@QT(G73"'@2<'M&T@QR$P!P$V)
MT$G!X`5-">A,BVPD($$!P$R)X$G![`)(P>`>18G`2HV,*9EY@EI,">!-B<5(
M,<))P>T;08G$3"'22#'Z2`'*3(G!2,'A!4P)Z4R+;"0H`=%,B=))P>H"2,'B
M'HG)2HV\+YEY@EI,"=))B<U(,=!)P>T;08G23"'`3#'@2`'X2(G/2,'G!4P)
M[TR+;"0P`<=,B<!)P>@"2,'@'HG_3XVD+)EY@EI,"<!)B?U(,<))P>T;08G`
M2"'*3#'23`'B28G\2<'D!4T)[$R+;"0X00'42(G*2,'I`DC!XAY%B>1/C90J
MF7F"6D@)RDV)Y4@QT$G![1N)T4@A^$PQP$P!T$V)XDG!X@5-">I,BVPD0$$!
MPDB)^$C![P)(P>`>18G23XV$*)EY@EI("?A-B=5(,<))P>T;B<=,(>)(,<I,
M`<)-B=!)P>`%30GH3(ML)$A!`=!,B>))P>P"2,'B'D6)P$J-C"F9>8):3`GB
M38G%2#'02<'M&T&)U$PAT$@Q^$@!R$R)P4C!X05,">E,BVPD4`'!3(G02<'J
M`DC!X!Z)R4J-O"^9>8):3`G028G-2#'"2<'M&T&)PDPAPDPQXD@!^DB)STC!
MYP5,">],BVPD6`'73(G"2<'H`DC!XAZ)_T^-I"R9>8):3`G"28G]2#'02<'M
M&T&)T$@AR$PQT$P!X$F)_$G!Y`5-">Q,BVPD8$$!Q$B)R$C!X!Y(P>D"18GD
M3XV4*IEY@EI("<A-B>5(,<))P>T;B<%((?I,,<),`=)-B>))P>(%30GJ3(ML
M)&A!`=)(B?I(P>\"2,'B'D6)TD^-A"B9>8):2`GZ38G52#'02<'M&XG73"'@
M2#'(3`'`38G02<'@!4T)Z$R+;"1P00'`3(G@2<'L`DC!X!Y%B<!*C8PIF7F"
M6DP)X$V)Q4@QPDG![1M!B<1,(=)(,?I(`<I,B<%(P>$%3`GI3(ML)'@!T4R)
MTDC!XAY)P>H"B<E*C;POF7F"6DP)TDF)S4@QT$G![1M!B=),(<!,,>!(`?A(
MB<](P><%3`GO3(NL)(`````!QTR)P$G!Z`)(P>`>B?]/C:0LF7F"6DP)P$F)
M_4@QPDG![1M!B<!((<I,,=),`>))B?Q)P>0%30GL1HTL(DB)RDC!Z0),BZ0D
MB````$C!XAY("<I/C90BF7F"6DV)[$@QT$G![!N)T4@A^$PQP$P!T$V)ZDG!
MX@5-">),BZ0DD````$$!PDB)^$C!X!Y(P>\"18G23XV$()EY@EI("?A-B=1(
M,<))P>P;B<=,(>I(,<I,`<)-B=!)P>`%30G@18G`3`'"38GH2<'M`DG!X!Y!
MB=1-">A,BZPDF````$PQP$PAT$J-C"F9>8):38GE2#'X2<'M&T@!R$R)X4C!
MX05,">F)R4@!R$R)T4G!Z@)(P>$>08G%3`G138G"18G`23'*1#'23(N4)*``
M``!*C;P7H>O9;DV)ZD@!UTR)ZDG!ZAM(P>(%3`G2B=)(`==,B>)(P>(>2<'L
M`D&)^DP#A"2H````3`GB28G,B<E(`XPDL````$DQU$0QX$V-I`"AZ]EN3(G0
M38G02<'H&TC!X`5,"<")P$D!Q$R)Z$G![0)(P>`>18G@3`GH28G5B=)(`Y0D
MN````$DQQ40Q[TR-K#FAZ]EN3(G!3(G'2,'O&TC!X05("?F)R4D!S4R)T4G!
MZ@)(P>$>1(GO3`G128G"B<!),<I%,>).C:02H>O9;DB)^DF)^DG!ZAM(P>(%
M3`G2B=))`=1,B<))P>@"2,'B'D6)XDP)PDF)R$@#A"3`````B<E),=!(`XPD
MR````$4QZ$Z-K`"AZ]EN3(G038G02<'H&TC!X`5,"<")P$D!Q4B)^$C![P)(
MP>`>18GH2`GX2(G7B=)(`Y0DT````$@QQT0QYTR-I#FAZ]EN3(G!3(G'2,'O
M&TC!X05("?F)R4D!S$R)T4G!Z@)(P>$>1(GG3`G128G"B<!(`X0DV````$DQ
MRD4QZDZ-K!*AZ]EN2(GZ28GZ2<'J&TC!X@5,"=*)TDD!U4R)PDG!Z`)(P>(>
M18GJ3`G"28G(B<E),=!(`XPDX````$4QX$Z-I`"AZ]EN3(G038G02<'H&TC!
MX`5,"<")P$D!Q$B)^$C![P)(P>`>18G@2`GX2(G7B=)(`Y0DZ````$@QQT0Q
M[TR-K#FAZ]EN3(G!3(G'2,'O&TC!X05("?F)R4D!S4R)T4G!Z@)(P>$>1(GO
M3`G128G"B<!(`X0D\````$DQRD4QXDZ-I!*AZ]EN2(GZ28GZ2<'J&TC!X@5,
M"=*)TDD!U$R)PDG!Z`)(P>(>18GB3`G"28G(B<E),=!%,>A.C:P`H>O9;DR)
MT$V)T$C!X`5)P>@;2`.,)/@```!,"<")P$D!Q4B)^$C![P)(P>`>18GH2`GX
M2(G7B=)(`Y0D``$``$@QQT0QYTR-I#FAZ]EN3(G!3(G'2,'O&TC!X05("?F)
MR4D!S$R)T4G!Z@)(P>$>1(GG3`G128G"B<!(`X0D"`$``$DQRD4QZDZ-K!*A
MZ]EN2(GZ28GZ2<'J&TC!X@5,"=*)TDD!U4R)PDG!Z`)(P>(>18GJ3`G"28G(
MB<E),=!%,>!.C:0`H>O9;DR)T$V)T$G!Z!M(P>`%3`G`2`.,)!`!``")P$D!
MQ$B)^$C![P)(P>`>18G@2`GX2(G7B=)(`Y0D&`$``$@QQT0Q[TR-K#FAZ]EN
M3(G!3(G'2,'O&TC!X05("?F)R4D!S4R)T4G!Z@)(P>$>1(GO3`G128G"B<!(
M`X0D(`$``$DQRD4QXDZ-I!*AZ]EN2(GZ28GZ2<'J&TC!X@5,"=*)TDD!U$R)
MPDG!Z`)(P>(>18GB3`G"28G(B<E),=!%,>A.C:P`H>O9;DR)T$V)T$G!Z!M(
MP>`%3`G`B<!)`<5(B?A(P>`>2,'O`D6)Z$@#C"0H`0``2`GX2(G7B=)(`Y0D
M,`$``$@QQT0QYTV)Q$B-C#FAZ]EN3(G'2<'L&TC!YP5,">=-B=1)P>H"2<'D
M'HG_30G428G"2`'YB<!-,>*)ST@#A"0X`0``13'J28G]3HV4$J'KV6Y(B?I)
MP>T;2,'B!4P)ZD$!TDR)PDG!Z`)(P>(>18G23`G"38G@18GD23'028G608G5
M1#'!38G02(V,"*'KV6Y,B=!)P>@;2,'@!4P)P$2-!`%(B?E(P>\"N-R\&X](
MP>$>2`GY20G.B<]((?I-(=9)"=9(BY0D0`$``$@!PDP!XDV)Q$P!\DV)QDG!
MY`5)P>X;30GT00'43(G22<'J`DC!XAY%B>1,"=)("=%)B=9!B=))(?Y,(<%,
M"?%,B[0D2`$``$D!QDT!]4V)YDP!Z4V)Y4G![AM)P>4%30GU28G600'-3(G!
M2<'H`DC!X1Y%B>U,"<%!B<A)"<Y-(>9,(<),"?),B[0D4`$``$D!QDP!]TV)
M[D@!^DR)[TG![AM(P><%3`GW`==,B>))P>P"2,'B'HG_3`GB2`G128G608G4
M32'&3"'I3`GQ3(NT)%@!``!)`<9-`?))B?Y,`=%)B?I)P>X;2<'B!4T)\DF)
MUD$!RDR)Z4G![0)(P>$>18G23`GI08G-20G.22'^3"'J3`GR3(NT)&`!``!)
M`<9-`?!-B=9,`<)-B=!)P>`%2<'N&TT)\$$!T$B)^DC![P)(P>(>18G`2`GZ
M2`G128G6B==-(>Y,(=%,"?%,B[0D:`$``$D!QDT!]$V)QDP!X4V)Q$G![AM)
MP>0%30GT28G600',3(G12<'J`DC!X1Y%B>1,"=%!B<I)"<Y-(<9,(=),"?),
MB[0D<`$``$D!QDT!]4V)YDP!ZDV)Y4G![AM)P>4%30GU00'53(G"2,'B'DG!
MZ`)%B>U,"<)("=%)B=9!B=!-(=9,(>%,"?%,B[0D>`$``$D!QDP!]TV)[D@!
M^4R)[TG![AM(P><%3`GW28G6`<],B>%)P>P"2,'A'HG_3`GA08G,20G.32'N
M3"'B3`GR3(NT)(`!``!)`<9-`?))B?Y,`=))B?I)P>X;2<'B!4T)\D$!TDR)
MZDG![0)(P>(>18G23`GJ2`G128G608G52"'Y32'F3`GQ3(NT)(@!``!)`<9-
M`?!-B=9,`<%-B=!)P>X;2<'@!4T)\$F)UD$!R$B)^4C![P)(P>$>18G`2`GY
MB<])"<Y-(=9((?I,"?),B[0DD`$``$D!QDT!]$V)QDP!XDV)Q$G![AM)P>0%
M30GT00'43(G22<'J`DC!XAY%B>1,"=)("=%)B=9!B=))(?Y,(<%,"?%,B[0D
MF`$``$D!QDT!]4V)YDP!Z4V)Y4G![AM)P>4%30GU28G600'-3(G!2<'H`DC!
MX1Y%B>U,"<%!B<A)"<Y-(>9,(<),"?),B[0DH`$``$D!QDP!]TV)[D@!^DR)
M[TG![AM(P><%3`GW`==,B>))P>P"2,'B'HG_3`GB2`G128G608G432'&3"'I
M3`GQ3(NT)*@!``!)`<9-`?))B?Y,`=%)B?I)P>X;2<'B!4T)\DF)UD$!RDR)
MZ4G![0)(P>$>18G23`GI08G-20G.22'^3"'J3`GR3(NT)+`!``!)`<9-`?!-
MB=9,`<)-B=!)P>X;2<'@!4T)\$$!T$B)^DC![P)(P>(>18G`2`GZ2`G128G6
MB==-(>Y,(=%,"?%,B[0DN`$``$D!QDT!]$V)QDP!X4V)Q$G![AM)P>0%30GT
M28G600',3(G12<'J`DC!X1Y%B>1,"=%)"<Y!B<I-(<9,(=),"?),B[0DP`$`
M`$D!QDT!]4V)YDP!ZDV)Y4G![AM)P>4%30GU00'53(G"2<'H`DC!XAY%B>U,
M"<)("=%)B=!!B==-(=!,(>%,"<%,BX0DR`$``$D!P$P!QTV)Z$@!^4R)[TG!
MZ!M(P><%3`G'1(T$.4R)YTG![`)(B=%(P><>3`GG08G\2`GY3"'I3"'B2`G*
M2(N,)-`!``!(`<%,`=%-B<)(`X0DV`$``$@!RDR)P4G!ZAM(P>$%3`G1B<E(
M`<I,B>E)P>T"2,'A'D&)TDP)Z4@)STF)S4&)SDPAQTTAY4D)_4J-/#A,B=!,
MB[PD^`$``$P![TV)U4C!X`5)P>T;3`GHB<!(`<=,B<!)P>@"2,'@'D&)_4D)
MP+C6P6+*3#'!,=%(BY0DX`$``$@!PDP!XDV)[$@!RDR)Z4G![!M(P>$%3`GA
M38G4B<E)P>0>2`'*2<'J`DD!QTT)XDV)Q(G118G`33'41#'G3(ND).@!``!)
M`<1-`?1)B<Y,`>=)B<Q)P>X;2<'D!4T)]$V)[DG![0))P>8>18GD30GU3(NT
M)/`!``!,`>=!B?Q)`<9-`?!-B=9-,>Y$,?)-B>9)`=!,B>))P>X;2,'B!4P)
M\HG220'02(G*2,'I`DC!XAY%B<9("<I$B=%-B>I),=),`?E,B[PD``(``$0Q
MUTV)\D@!STR)\4C!X05)P>H;20''3`G1B<E(`<],B>%)P>P"2,'A'D&)^DD)
MS$2)Z4F)U8G233'E3`'Y3(N\)!`"``!%,>A-B=5)`<A,B=%)P>T;20''2,'A
M!4P)Z8G)20'(3(GQ2<'N`DC!X1Y%B<5,"?%,B[0D"`(``$D!QDP!\DV)YDDQ
MSD0Q]TV)[D@!UTR)ZDG![AM(P>(%3`GRB=)(`==,B=))P>H"2,'B'D&)_DD)
MTD2)XDF)S(G)3`'Z33'43(N\)"`"``!%,>!-B?1)`=!,B?))P>P;20''2,'B
M!4P)XHG220'03(GJ2<'M`DC!XAY%B<1,">I,BZPD&`(``$D!Q4P!Z4V)U4DQ
MU40Q[TV)Y4@!STR)X4G![1M(P>$%3`GIB<E(`<],B?%)P>X"2,'A'D&)_4D)
MSD2)T4F)THG233'R3`'Y3(N\)#`"``!%,=!-B>I)`<A,B>E)P>H;2,'A!4P)
MT8G)20'(3(GA2,'A'DG![`)%B<))`<=,">%,BZ0D*`(``$D!Q$P!XDV)]$DQ
MS$0QYTV)U$@!UTR)TDG![!M(P>(%3`GBB=)(`==,B>I)P>T"2,'B'D&)_$D)
MU42)\DF)SHG)33'N3`'Z3(N\)$`"``!%,?!-B>9)`=!,B>))P>X;2,'B!4P)
M\HG220'03(G22<'J`DC!XAY%B<9,"=),BY0D.`(``$D!PDP!T4V)ZDDQTD0Q
MUTV)\D@!STR)\4C!X05)P>H;20''3`G1B<E(`<],B>%)P>P"2,'A'D&)^DD)
MS$2)Z4F)U8G233'E3`'Y3(N\)&`"``!%,>A-B=5)`<A,B=%)P>T;2,'A!4P)
MZ8G)20'(3(GQ2<'N`DC!X1Y%B<5,"?%,B[0D2`(``$D!QDP!\DV)YD6)Y$DQ
MSD0Q]TV)[D@!UTR)ZDG![AM(P>(%3`GRB=)(`==,B=))P>H"2,'B'D&)_DD)
MTDB+E"10`@``2`'"20'42(G*B<E,,=))`<=$,<)-B?!)`=1,B?))P>@;2,'B
M!4P)PHG220'43(GJ2<'M`DC!XAY%B>!,">I,BZPD6`(``$D!Q4P!Z4V)U4DQ
MU40Q[TV)Q4@!STR)P4G![1M(P>$%3`GIB<E(`<],B?%)P>X"2,'A'D&)_4D)
MSD2)T4F)THG233'R3`'Y3(N\)'`"``!%,>)-B>Q,`=%-B>I)P>P;2<'B!4T)
MXDV)Q$6)TDG!Y!Y,`=%)P>@"20''30G@3(ND)&@"``!!B<I)`<1(`X0D>`(`
M`$P!XDV)]$P!R$TQQ$0QYTV)U$@!UTR)TDG![!M(P>(%3`GB38GL2<'M`DG!
MY!Z)TDT)Y46)]$V)QD@!UTTQ[HGZ30'\18G`1#'Q28G63`'`38GH3`'A28G4
M2<'N&TG!Y`5-"?1$`>%-B=1)P>H"2<'D'HG)30GB33'01#''28G(2`'X2(G/
M2,'G!4G!Z!L!Z4$!VDP)QT0#;B!(B4X(`?A,B5882(D&2(G02,'J`DC!X!Y,
MB6X@2`G01`'82(E&$$B+A"2(`@``9$@K!"4H````=1)(@<28`@``6UU!7$%=
M05Y!7\/_%55G```/'T0``$B#[`B_@````/\5&6<``&8/;P4920``2,=`,```
M```/$0!F#V\%%DD``,=`>``````/$4`09@]O!1-)```/$4`@2(/$",-F+@\?
MA```````05=(8\))B?=!5DF)_D%5051)B<1528UN.%-(@^P82(M_*$F+5C"-
M#,=(.?E)8WYX28E.*$B#T@!(P>@=2`'028E&,(7_=&]!O4````!)C6XX02G]
M13GE10]/[$@![TECU4@Y]P^")@$``$B-'!9(.?YS"4@YWP^"N0$``$R)_O\5
M(V8``$&+1GA$`>A!B49X@_A`=!-(@\086UU!7$%=05Y!7\,/'T``3(GW12GL
M28G?Z(KH__]!@_P_?GQ)C49X3(G[38UO0$B)1"0(ZU!FD$B+1"0(2#G##X)<
M`0``38GO\P]O`TR)]T&#[$!(@\-`28/%0`\110#S#V]#T`\111#S#V]#X`\1
M12#S#V]#\`\113#H*.C__T&#_#]^&D@YW7*M38GO2#GK<[9,.>USL>E]Q___
M#Q\`26/$3#G]<D!).>]S#4F-%`=(.=4/@F#'__](@_@(<UBH!`^%P````$B%
MP`^%EP```$6)9GA(@\086UU!7$%=05Y!7\,/'T``2(U4!0!).==SR.DCQ___
MD$B-!!=(.<8/@A7'__](C1P6Z=;^__]F+@\?A```````28L72(U-"$R)_DB#
MX?A)B58X28M4!_A(B50%^$@IS4@!Z$@I[DB#X/A(@_@(<HI(@^#X,=)(BSP6
M2(D\$4B#P@A(.<)R[^EN____#Q]$``!!#[8708A6.*@"#X19____00^W5`?^
M9HE4!?[I2?___T&+%T&)5CA!BU0'_(E4!?SI-/___^EXQO__Z7/&__^0059,
MC78X055!5%5(B?U33(MN*$B)\TR+9C!,B>A(P>@#@^`_C4@!QD0&.(!(8\%,
M`?"#^3@/CGT!``"Z0````"G*=`\QR8G.@\$!Q@0P`#G1<O-(B=_HI>;__V8/
M[\`/$4,X2<=&,`````!!#Q%&$$$/$48@3(GB00^VQ4V)Z$R)[TC!ZAA(P>`(
M3(GA2<'H$$F)T4R)ZDC![Q@/MO9,B>)(P>D02`GP00^V\`^VR4C!X`A("?!`
M#[;W2(G?2,'@"$@)\$$/MO1(P>`(2`GP#[;V00^VT4C!X`A("?!(P>`(2`G(
M2,'@"$@)T$B)0W#H#.;__TB+`TB)WTC!Z!B(10!(BP-(P>@0B$4!2(L#B&4"
M2(L#B$4#2(M#"$C!Z!B(101(BT,(2,'H$(A%!4B+0PB(909(BT,(B$4'2(M#
M$$C!Z!B(10A(BT,02,'H$(A%"4B+0Q"(90I(BT,0B$4+2(M#&$C!Z!B(10Q(
MBT,82,'H$(A%#4B+0QB(90Y(BT,8B$4/2(M#($C!Z!B(11!(BT,@2,'H$(A%
M$4B+0R"(91)(BT,@B$436UU!7$%=05[_)6MD```/'P"Z.````#'V*<J#^@AS
M*O;"!'5MA=(/A*+^___&``#VP@(/A);^__\QR6:)3!#^Z8K^__\/'T0``(G1
M2,<``````$C'1`CX`````$B-2`A(@^'X2"G(`<*#XOB#^@@/@EK^__^#XO@Q
MP(G'@\`(2(DT.3G0<O/I0_[__V8/'T0``,<``````,=$$/P`````Z2K^__]0
M6,,`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````)7,O)7,`1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R
M;F%L<SHZ4$%2.CI"3T]4`&5X90`O<')O8R\E:2\E<P`N`%!!4E]414U0`%!!
M4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)0@!015),-4]05`!015),
M24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@!005)?
M1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"54<`4$%27T=,3T)!3%]4
M35!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#
M3$5!3@`Q`&QS965K(&9A:6QE9`!R96%D(&9A:6QE9`!,1%],24)205)97U!!
M5$@`4UE35$5-`"]T;7``5$5-4$1)4@!435``55-%4@!54T523D%-10`E,#)X
M`'!A<BT`)7,E<R5S)7,`<&%R;``N<&%R`'-H;W)T(')E860`)7,E<V-A8VAE
M+25S)7,`)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S`!@`<&5R;``P
M`%!!4CHZ4&%C:V5R.CI615)324].`#$N,#8T`"UE`"TM````)7,Z(&-R96%T
M:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\]
M)6DI"@```````"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A
M9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N
M*0H```````!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0``````
M````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y
M("5S(&9A:6QE9"`H97)R;F\])6DI"@``````````979A;"`G97AE8R`O=7-R
M+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI
M;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!
M4E]-04=)0RP@)$9)3$5?;V9F<V5T7W-I>F4L("1C86-H95]N86UE7W-I>F4I
M.PI"14=)3B!["B1005)?34%'24,@/2`B7&Y005(N<&U<;B(["B1&24Q%7V]F
M9G-E=%]S:7IE(#T@-#L@("`C('!A8VLH(DXB*0HD8V%C:&5?;F%M95]S:7IE
M(#T@-#`["B102UI)4%]-04=)0R`](")02UPP,#-<,#`T(CL*?0IS=6(@9FEN
M9%]P87)?;6%G:6,*>PIM>2`H)&9H*2`]($!?.PIM>2`D8VAU;FM?<VEZ92`]
M(#8T("H@,3`R-#L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D9F@["FUY("1P
M;W,@/2`H)'-I>F4M,2D@+2`H)'-I>F4M,2D@)2`D8VAU;FM?<VEZ93L@("`@
M("`C($Y/5$4Z("1P;W,@:7,@82!M=6QT:7!L92!O9B`D8VAU;FM?<VEZ90IW
M:&EL92`H)'!O<R`^/2`P*2!["G-E96L@)&9H+"`D<&]S+"`P.PIR96%D("1F
M:"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H)%!!4E]-04=)0RD["FEF
M("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-04=)0RDI(#X](#`I('L*
M<F5T=7)N("1P;W,@*R`D:3L*?0HD<&]S("T]("1C:'5N:U]S:7IE.PI]"G)E
M='5R;B`M,3L*?0IM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE
M+"`E36]D=6QE0V%C:&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2![
M"G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*
M<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA
M;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<5M296UO=FEN9R!F:6QE
M<R!I;B`B)'!A<E]T96UP(ETI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B
M('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD
M:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7
M:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]
M/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H
M)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIM
M>2`D9FEL96YA;64@/2`D=&UP+3YF:6QE;F%M93L*<')I;G0@)'1M<"`\/"(N
M+BXB.PIX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P
M87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K
M"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<D9FEL96YA
M;64G"BXN+@IC;&]S92`D=&UP.PIC:&UO9"`P-S`P+"`D9FEL96YA;64["FUY
M("1C;60@/2`B)&9I;&5N86UE(#XO9&5V+VYU;&P@,CXF,2`F(CL*<WES=&5M
M*"1C;60I.PIO=71S*'%Q6U-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O
M('!E<F9O<FT@8VQE86YU<#H@)&9I;&5N86UE72D["GT*?2!]"D)%1TE.('L*
M26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z
M.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T
M(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)7-Y<R`]("@*<&%T:%]S97`@("`@
M/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@
M(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@
M.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@
M)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*;W5T<RAQ<5M<)'!R
M;V=N86UE(#T@(B1P<F]G;F%M92)=*3L*7W-E=%]P87)?=&5M<"@I.PIO=71S
M*'%Q6UPD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2)=*3L*;7D@
M*"1S=&%R=%]P;W,L("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI.PI-04=)0SH@
M>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*=6YL97-S("AO<&5N
M(%]&2"P@)SPZ<F%W)RP@)'!R;V=N86UE*2!["F]U=',H<7%;0V%N)W0@<F5A
M9"!F<F]M(&9I;&4@(B1P<F]G;F%M92)=*3L@(",@9&]N)W0@=7-E("0A(&AE
M<F4@87,@:70@<F5Q=6ER97,@17)R;F\N<&T*;&%S="!-04=)0SL*?0IM>2`D
M;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H*E]&2"D["FEF("@D;6%G:6-?
M<&]S(#P@,"D@>PIO=71S*'%Q6T-A;B=T(&9I;F0@;6%G:6,@<W1R:6YG("(D
M4$%27TU!1TE#(B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,[
M"GT*;W5T<R@B1F]U;F0@4$%2(&UA9VEC(&%T('!O<VET:6]N("1M86=I8U]P
M;W,B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ
M92`M(&QE;F=T:"@B7#!#04-(12(I+"`P.PIR96%D(%]&2"P@)&)U9BP@;&5N
M9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&YE(")<,$-!0TA%(B`F)B`D8G5F
M(&YE(")<,$-,14%.(BD@>PIO=71S*").;R!C86-H92!M87)K97(@9F]U;F0B
M*3L*;&%S="!-04=)0SL*?0IO=71S*'%Q6T-A8VAE(&UA<FME<B`B)&)U9B(@
M9F]U;F1=*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?
M<VEZ92P@,#L*<F5A9"!?1D@L("1B=68L("1&24Q%7V]F9G-E=%]S:7IE.PIM
M>2`D;V9F<V5T(#T@=6YP86-K*").(BP@)&)U9BD["F]U=',H(D]F9G-E="!F
M<F]M('-T87)T(&]F($9)3$5S(&ES("1O9F9S970B*3L*<V5E:R!?1D@L("1M
M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92`M("1O9F9S970L(#`["B1S
M=&%R=%]O9E]&24Q%7W-E8W1I;VX@/2!T96QL(%]&2#L*;7D@)7)E<75I<F5?
M;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(R!R96%D('1H92!F:7)S="`B1DE,12(*=VAI;&4@*"1B=68@97$@
M(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@
M=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H
M<7%;56YP86-K:6YG($9)3$4@(B1F=6QL;F%M92(N+BY=*3L*;7D@)&-R8R`]
M("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U
M;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ
M+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L
M("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A
M;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N
M86UE(#T@7W-A=F5?87,H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z
M.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!
M4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]
M"F5L<V4@>PHD36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B
M=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*)')E<75I
M<F5?;&ES='LD9G5L;&YA;65]*RL["GT*<F5A9"!?1D@L("1B=68L(#0["GT*
M;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\[
M"G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@
M/2`D36]D=6QE0V%C:&5[)&UO9'5L97T["G)E='5R;B!U;FQE<W,@)&EN9F\[
M"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5].PHD24Y#>R1M;V1U;&5]
M(#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!
M3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/
M.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@(D-A;B=T(&-R96%T92!T96UP
M(&9I;&4Z("0A(CL*)&9H+3YB:6YM;V1E*"D["B1F:"T^<')I;G0H)&EN9F\M
M/GMB=69]*3L*)&9H+3YS965K*#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@
M>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&EN9F\M/GMC<F-]+G!M(BP@
M)&EN9F\M/GMB=69]*3L*)&EN9F\M/GMF:6QE?2`]("1F:6QE;F%M93L*;W!E
M;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE;F%M92!O<B!D:64@<7%;0V%N)W0@
M<F5A9"`B)&9I;&5N86UE(CH@)"%=.PIR971U<FX@)&9H.PI]"F1I92`B0F]O
M='-T<F%P<&EN9R!F86EL960Z(&-A;B=T(&9I;F0@;6]D=6QE("1M;V1U;&4A
M(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(
M96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ
M2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER
M92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@
M)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@
M;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@
M+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@
M)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<
M+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]
M"FEF("@D8G5F(&YE("102UI)4%]-04=)0RD@>PIO=71S*'%Q6TYO('II<"!F
M;W5N9"!A9G1E<B!&24Q%('-E8W1I;VX@:6X@9FEL92`B)'!R;V=N86UE(ETI
M.PIL87-T($U!1TE#(#L*?0HD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0[
M("`@("`@("`@("`@("`@(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A<E]A<F=S
M.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E
M;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M
M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0II9B`H(21S=&%R=%]P;W,@;W(@
M*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@
M)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P
M87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?
M<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2![
M"G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%2
M1U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?
M=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/
M0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP
M=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V
M86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P
M87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#([
M"GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L
M<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D
M,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2![
M"F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E;B!L
M;V<@9FEL92`B)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C
M:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D
M9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET
M7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD
M(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F
M;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC
M.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E
M($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R
M(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2![
M"F]P96X@;7D@)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!F
M:6YD('!A<B!F:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ1FEL
M92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R
M;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/
M2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P
M87(B73L*?0IM>2`E;65T85]P87(@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D
M;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^
M(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@
M/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FEF("AD969I;F5D("1P
M87(I('L*;W!E;B!M>2`D<&@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A
M;B=T(')E860@<&%R(&9I;&4@(B1P87(B.B`D(5T["FUY("1B=68["G)E860@
M)'!H+"`D8G5F+"`T.PID:64@<7%;(B1P87(B(&ES(&YO="!A('!A<B!F:6QE
M72!U;FQE<W,@)&)U9B!E<2`D4$M:25!?34%'24,["F-L;W-E("1P:#L*?0I#
M<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U
M="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U)$5U(H*2!\
M($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A;B=T
M(&-R96%T92!F:6QE("(D;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*<V5E
M:R!?1D@L(#`L(#`["FUY("1L;V%D97(["FEF("AD969I;F5D("1S=&%R=%]O
M9E]&24Q%7W-E8W1I;VXI('L*<F5A9"!?1D@L("1L;V%D97(L("1S=&%R=%]O
M9E]&24Q%7W-E8W1I;VX["GT@96QS92!["FQO8V%L("0O(#T@=6YD968["B1L
M;V%D97(@/2`\7T9(/CL*?0II9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@
M)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH
M7"1L;V%D97(L("0P*3L*?0HD9F@M/G!R:6YT*"1L;V%D97(I"F]R(&1I92!Q
M<5M%<G)O<B!W<FET:6YG(&QO861E<B!T;R`B)&]U="(Z("0A73L*:68@*"1B
M=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI
M=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I
M.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L
M92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI
M8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D[
M"GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\?"!F;W)E86-H($!I;F,["FUY("5F
M:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D
M7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z
M.D-O;F9I9WML:6)?97AT?3L@("`@("`@("`C(%A86"!L:6)?97AT('9S(&1L
M97AT(#\*;7D@)7=R:71T96X["F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES
M("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N86UE*3L*:68@*&1E9FEN960H;7D@
M)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD:V5Y?2DI('L**"1F:6QE
M+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*?0IE;'-E('L*9F]R96%C:"!M>2`D
M9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^(&U\7EQ1)&1I<EQ%+R@N*BDD?&DI
M('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)#$I.PIL87-T.PI]"FEF("@D
M:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO*"XJ*21\*2!["FEF("AM>2`D<F5F
M(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F
M+"`D,2D["FQA<W0["GT*:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N
M86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*?0IN97AT('5N
M;&5S<R!D969I;F5D("1N86UE.PIN97AT(&EF("1W<FET=&5N>R1N86UE?2LK
M.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?
M97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ<5M086-K:6YG($9)3$4@(B5S(BXN
M+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92DI.PIM>2`D
M8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^
M>V)U9GT["GT*96QS92!["FQO8V%L("0O(#T@=6YD968["F]P96X@;7D@)'1H
M+"`G/#IR87<G+"`D9FEL92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&4B
M.B`D(5T["B1C;VYT96YT(#T@/"1T:#X["F-L;W-E("1T:#L*4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB961D960^+R1N
M86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN
M*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN
M97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0HD9F@M/G!R
M:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2P*<W!R
M:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C
M;VYT96YT*2P@)&YA;64I+`IP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DL
M"B1C;VYT96YT*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!E;6)E9&1E9"!&
M24Q%('1O("(D;W5T(CH@)"%=.PIO=71S*'%Q6U=R:71T96X@87,@(B1N86UE
M(ETI.PI]"GT*:68@*"1Z:7`I('L*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H
M)&9H*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+"F]R(&1I92!Q<5M%<G)O<B!W
M<FET:6YG('II<"!P87)T(&]F("(D;W5T(ET["GT*:68@*"1M971A7W!A<GMC
M;&5A;GTI('L*)&9H+3YP<FEN="@B7#!#3$5!3B(I.PI]"F5L<V4@>PII9B`H
M(61E9FEN960@)&-A8VAE7VYA;64I('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!
M+3YN97<H,2D["G-E96L@)&9H+"`P+"`P.PHD8W1X+3YA9&1F:6QE*"1F:"D[
M"G-E96L@)&9H+"`P+"`R.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I9V5S
M=#L*?0HD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@)&-A
M8VAE7VYA;65?<VEZ93L*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@D8V%C:&5?
M;F%M95]S:7IE("T@;&5N9W1H("1C86-H95]N86UE*3L*)&9H+3YP<FEN="@D
M8V%C:&5?;F%M92P*(EPP0T%#2$4B*3L*?0IM>2`D;V9F<V5T(#T@)&9H+3YT
M96QL("T@;&5N9W1H*"1L;V%D97(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D
M;V9F<V5T*2P*)%!!4E]-04=)0RD["B1F:"T^8VQO<V4@;W(@9&EE('%Q6T5R
M<F]R('=R:71I;F<@=')A:6QE<B!O9B`B)&]U="(Z("0A73L*8VAM;V0@,#<U
M-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T
M7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V
M>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*
M<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE
M=SL@("`@("`@("`@("`@("`@("`@("`@("`@("`@(",@07)C:&EV93HZ6FEP
M(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL96YO
M*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E;B@I(&9A:6QE9#H@)"%=.PI!
M<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM>2`D>FEP(#T@
M07)C:&EV93HZ6FEP+3YN97<["B@D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H
M)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@
M9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P<F]G;F%M92)=
M.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V-"`J(#$P,C0I.PIP=7-H
M($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA
M;65](#T@)'II<#L*;W5T<R@B17AT<F%C=&EN9R!Z:7`N+BXB*3L*:68@*&1E
M9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H
M:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@
M*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?
M;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R
M7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C
M:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q
M.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!
M4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F
M("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H
M<7%;4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E
M>&ES=',@870@(B1D97-T7VYA;64B72D["GT@96QS92!["F]U=',H<7%;17AT
M<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(N+BY=*3L*
M*"1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*2`]/2!!
M<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!E>'1R86-T
M:6YG('II<"!M96UB97(@=&\@(B1D97-T7VYA;64B73L*8VAM;V0H,#4U-2P@
M)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@
M*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE
M<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;
M("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M
M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-
M17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E
M871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E
M;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S
M96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I
M;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE
M("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I
M<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97([
M"G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R
M;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A
M<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(
M96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER
M92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,
M;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E
M<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I
M<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR97%U:7)E
M(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*
M<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&
M:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L
M('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A
M;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R
M8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA
M<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E
M<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F."!]
M.PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?
M5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E
M;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%
M3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-
M4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D
M969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U
M<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED
M*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO
M9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]
M"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60[
M"GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[
M55-%4GT@?'P@)U-94U1%32<["GT*;7D@)'-T;7!D:7(@/2`B)'!A=&@D<WES
M>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@
M)'-T;7!D:7(L(#`W-34["FUY("1C86-H95]D:7(["FEF("@D14Y6>U!!4E]#
M3$5!3GTI('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*?0IE;'-E('L*;W!E
M;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M92!O<B!D:64@<7%;0V%N)W0@
M<F5A9"`B)'!R;V=N86UE(CH@)"%=.PII9B`H*&UY("1M86=I8U]P;W,@/2!F
M:6YD7W!A<E]M86=I8R@D9F@I*2`^/2`P*2!["G-E96L@)&9H+"`D;6%G:6-?
M<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*2P@
M,#L*;7D@)&)U9CL*<F5A9"`D9F@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I
M.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("1M86=I8U]P
M;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I"BT@
M)&-A8VAE7VYA;65?<VEZ92P@,#L*<F5A9"`D9F@L("1B=68L("1C86-H95]N
M86UE7W-I>F4["B1B=68@/7X@<R]<,"\O9SL*)&-A8VAE7V1I<B`](")C86-H
M92TD8G5F(CL*?0I]"F-L;W-E("1F:#L*?0II9B`H(21C86-H95]D:7(I('L*
M)&-A8VAE7V1I<B`](")T96UP+20D(CL*)$5.5GM005)?0TQ%04Y](#T@,3L*
M?0HD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L:6U])&-A8VAE7V1I<B(["FUK9&ER
M("1S=&UP9&ER+"`P-S4U.PHD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIL
M87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D
M14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]S879E7V%S('L*;7D@
M*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@
M/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*
M;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["FUY("1F:#L**&]P96X@
M)&9H+"`G/CIR87<G+"`D=&5M<&YA;64I"B8F("AP<FEN="`D9F@@)&-O;G1E
M;G1S*0HF)B`H8VQO<V4@)&9H*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R`B
M)'1E;7!N86UE(CH@)"%=.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E
M9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@
M=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@
M7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%
M?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA
M;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-
M4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I
M('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G
M;F%M92P@)'-Y<WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/
M1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`^/2`P
M*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N
M(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921S>7-[7V5X97TB*2![
M"B1P<F]G;F%M92`N/2`D<WES>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H
M(&UY("1D:7(@*'-P;&ET("]<421S>7-[<&%T:%]S97!]7$4O+"`D14Y6>U!!
M5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER
M(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D<WES>U]D96QI;7U<
M120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M
M921S>7-[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD
M<')O9VYA;64D<WES>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[
M7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E
M;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@
M)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D
M<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N
M)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@
M)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I
M;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M
M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D<WES>U]D96QI
M;7U<12DO)'!W9"1S>7-[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]
M("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM0
M05)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD
M14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@
M5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I("D@>PID96QE=&4@
M)$5.5GLB4$%27R1?(GT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@
M1$5"54<@+RD@>PHD14Y6>R)005)?)%\B?2`]("1%3E9[(E!!4E]'3$]"04Q?
M)%\B?2!I9B!E>&ES=',@)$5.5GLB4$%27T=,3T)!3%\D7R)].PI]"FEF("@D
M14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"GT*
M<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R
M:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]
M"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R
M97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H
M;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD
M;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q
M=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M
M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7%;<&%R+G!L.B!#86XG="!O<&5N
M('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER
M96-T;W)Y7&Y="G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*
M0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO
M*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*
M0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH
M*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?
M7T5.1%]?"@``0T%#2$4``'!E<FQX<VDN8P`````````!(T5G`````(FKS>\`
M````_MRZF`````!V5#(0`````/#ATL,````````````````!&P,[[````!P`
M``!P?___"`$``*!___^,`@``HG___V0&``#`?___:`4``""#__\P`0``X(/_
M_WP!``!PA/__H`$``."%___<`0``4(C__R@"``"@B/__1`(``-"(__]8`@``
M`(K__Z0"```0BO__N`(``$",__\(`P``<(S__R0#``"@C?__8`,``*"2__^L
M`P``$)/__\@#``#0D___Y`,``""5__\D!```0)7__SP$```0EO__>`0```"=
M___T!```8)___S`%```PH/__F`4``*"V___H!0``\+;__P`&```PN?__A`8`
M```````4``````````%Z4@`!>!`!&PP'")`!```D````'````&!^__\@````
M``X01@X82@\+=PB``#\:.RHS)"(`````2````$0```#H@?__M@````!"#A"/
M`D(.&(X#0@X@C01"#BB,!4$.,(8&00XX@P=$#D`"70H..$0.,$$.*$(.($(.
M&$(.$$(."$@+`"````"0````7(+__X0`````00X0@P)'#K`!`G0*#A!!#@A!
M"S@```"T````R(+__VT!````0@X0C0)"#AB,`T$.((8$00XH@P5'#M`!?@H.
M*$$.($$.&$(.$$(."$<+`$@```#P````_(/__V("````0@X0CP)$#AB.`T(.
M((T$0@XHC`5!#C"&!D$..(,'1PY@`S8!"@XX00XP00XH0@X@0@X80@X00@X(
M10L8````/`$``""&__]-`````$$.$(,"<@X(````$````%@!``!4AO__)@``
M```````P````;`$``'"&__\J`0```$$.$(8"00X8@P-'#I@@3`Z80$D.P$`"
MWPH.&$0.$$$."$8+%````*`!```,??__`@`````.P$"#`X8"$````+@!``!4
MA___!0````````!,````S`$``%"'__\G`@```$(.$(\"0@X8C@-"#B"-!$(.
M*(P%00XPA@9!#CB#!T<.N"!,#O`A`FX*#CA!#C!!#BA"#B!"#AA"#A!"#@A+
M"Q@````<`@``,(G__R0`````00X0@P)=#@@````X````.`(``$2)__\B`0``
M`$$.$(8"00X8@P-'#I@@20ZP(`+*"@X800X000X(0@M:"@X82`X000X(30M(
M````=`(``#B*___U!````$(.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9(#CB#
M!T0.4`.@!`H..$L.,$$.*$(.($(.&$(.$$(."$4+&````,`"``#LCO__8@``
M``!$#B`"3@H."$8+`!@```#<`@``0(___[$`````00X000X(1P[@`0`\````
M^`(``.2/__]/`0```$(.$(P"00X8A@-!#B"#!$@,"Z"`!%$-!T0.L(`$`N`*
M#B!!#AA!#A!"#@A+"P``%````#@#``#TD/__'P````!$#A!:#@@`.````%`#
M``#\D/__Q0````!"#A"-`D(.&(P#2`X@A@1!#BB#!40.0`)""@XH1`X@00X8
M0@X00@X(3`L`>````(P#``"0D?__Y`8```!"#A"/`DD.&(X#3@X@C01.#BB,
M!4T.,(8&1@XX@P='#K`#`VT""@XX1`XP00XH0@X@0@X80@X00@X(10L#D`$.
MN`-%#L`#6`ZX`T$.L`,#&`$*#CA$#C!!#BA"#B!"#AA"#A!"#@A-"P```#@`
M```(!```!)C__U,"````0@X0C0))#AB,`T$.((8$00XH@P5$#D`#;0$*#BA!
M#B!!#AA"#A!"#@A$"S0```!$!```*)K__\H`````00X0A@)!#AB#`T0.,`)7
M"@X800X000X(00L"6@H.&$0.$$$."$4++````'P$``!0>O__$P(```!!#A"&
M`D$.&(,#1`Y0`V\!"@X80PX000X(00L`````3````*P$``"0FO__:Q8```!"
M#A"/`D(.&(X#0@X@C01"#BB,!4$.,(8&00XX@P='#M`%`TD6"@XX00XP00XH
M0@X@0@X80@X00@X(00L````4````_`0``+"P__]&`````$0.$`)!#@A@````
M%`4``.BP__\_`@```$(.$(\"2`X8C@-%#B"-!$(.*(P%1`XPA@9%#CB#!T0.
M4`)["@XX00XP00XH0@X@0@X80@X00@X(10L"R0H..$$.,$$.*$(.($(.&$(.
M$$(."$4+'````'@%```V>?__`@`````.4(,'A@:,!8T$C@./`@`\````F`4`
M`*2R__]+`@```$(.$(X"1@X8C0-"#B",!$$.*(8%1`XP@P8#F0$*#BA!#B!"
M#AA"#A!"#@A)"P``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````(`C````````(",````````_80```````-I@
M````````]V````````!080```````````````````0````````#0`@``````
M``$`````````VP(````````=``````````X$````````#```````````(```
M``````T`````````&UP````````9`````````-"[````````&P`````````(
M`````````!H`````````V+L````````<``````````@`````````]?[_;P``
M``"(`P````````4`````````@`T````````&`````````(`$````````"@``
M```````L!`````````L`````````&``````````5````````````````````
M`P````````#HO0````````(`````````&``````````4``````````<`````
M````%P````````"(&`````````<`````````L!$````````(`````````-@&
M````````"0`````````8`````````!X`````````"`````````#[__]O````
M``$```@`````^?__;P`````(````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````"+P`````````````````````````````)B``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````P`````````I005(N<&T*``````````#H8@```````$=#
M0SH@*$%L<&EN92`Q-"XS+C`I(#$T+C,N,```+G-H<W1R=&%B`"YN;W1E+F=N
M=2YP<F]P97)T>0`N;F]T92YG;G4N8G5I;&0M:60`+FEN=&5R<``N9VYU+FAA
M<V@`+F1Y;G-Y;0`N9'EN<W1R`"YR96QA+F1Y;@`N<F5L82YP;'0`+FEN:70`
M+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N
M:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N9&%T82YR96PN<F\`+F1Y;F%M:6,`
M+F=O=``N9&%T80`N8G-S`"YC;VUM96YT````````````````````````````
M````````````````````````````````````````````````````````````
M````"P````<````"`````````!@#````````&`,````````P````````````
M````````"````````````````````!X````'`````@````````!(`P``````
M`$@#````````)`````````````````````0````````````````````Q````
M`0````(`````````;`,```````!L`P```````!D````````````````````!
M````````````````````.0```/;__V\"`````````(@#````````B`,`````
M``#T``````````4`````````"````````````````````$,````+`````@``
M``````"`!````````(`$``````````D````````&`````0````@`````````
M&`````````!+`````P````(`````````@`T```````"`#0```````"P$````
M```````````````!````````````````````4P````0````"`````````+`1
M````````L!$```````#8!@````````4`````````"``````````8````````
M`%T````$````0@````````"(&````````(@8````````&``````````%````
M%`````@`````````&`````````!G`````0````8``````````"``````````
M(`````````,````````````````````!````````````````````8@````$`
M```&`````````!`@````````$"`````````@````````````````````$```
M```````0`````````&T````!````!@````````!`(````````$`@````````
MVSL``````````````````"````````````````````!S`````0````8`````
M````&UP````````;7`````````,````````````````````!````````````
M````````>0````$````"``````````!@`````````&````````"@0```````
M````````````$````````````````````($````!`````@````````"@H```
M`````*"@````````[`````````````````````0```````````````````"/
M`````0````(`````````D*$```````"0H0```````-@%````````````````
M```(````````````````````F0````X````#`````````-"[````````T*L`
M```````(````````````````````"``````````(`````````*4````/````
M`P````````#8NP```````-BK````````"`````````````````````@`````
M````"`````````"Q`````0````,`````````X+L```````#@JP```````"@`
M```````````````````0````````````````````O@````8````#````````
M``B\````````"*P```````#@`0````````8`````````"``````````0````
M`````,<````!`````P````````#HO0```````.BM````````$`(`````````
M``````````@`````````"`````````#,`````0````,``````````,``````
M````L````````"`````````````````````(````````````````````T@``
M``@````#`````````"#`````````(+````````"0````````````````````
M(````````````````````-<````!````,````````````````````""P````
M````'`````````````````````$``````````0`````````!`````P``````
M```````````````````\L````````.`````````````````````!````````
)````````````
